==> openshift-model-console-5.11.2-sources.jar: io/fabric8/openshift/api/model/console/v1/CLIDownloadLinkFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class CLIDownloadLinkFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<A>{
  public CLIDownloadLinkFluentImpl() {
  }
  public CLIDownloadLinkFluentImpl(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance) {
    this.withHref(instance.getHref()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String href;
  private java.lang.String text;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHref() {
    return this.href;
  }
  public A withHref(java.lang.String href) {
    this.href=href; return (A) this;
  }
  public java.lang.Boolean hasHref() {
    return this.href != null;
  }
  
  /**
   * Method is deprecated. use withHref instead.
   */
  @java.lang.Deprecated
  public A withNewHref(java.lang.String arg0) {
    return (A)withHref(new String(arg0));
  }
  public java.lang.String getText() {
    return this.text;
  }
  public A withText(java.lang.String text) {
    this.text=text; return (A) this;
  }
  public java.lang.Boolean hasText() {
    return this.text != null;
  }
  
  /**
   * Method is deprecated. use withText instead.
   */
  @java.lang.Deprecated
  public A withNewText(java.lang.String arg0) {
    return (A)withText(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CLIDownloadLinkFluentImpl that = (CLIDownloadLinkFluentImpl) o;
    if (href != null ? !href.equals(that.href) :that.href != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(href,  text,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-console-5.12.3-sources.jar: io/fabric8/openshift/api/model/console/v1/CLIDownloadLinkFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class CLIDownloadLinkFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<A>{
  public CLIDownloadLinkFluentImpl() {
  }
  public CLIDownloadLinkFluentImpl(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance) {
    this.withHref(instance.getHref()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String href;
  private java.lang.String text;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHref() {
    return this.href;
  }
  public A withHref(java.lang.String href) {
    this.href=href; return (A) this;
  }
  public java.lang.Boolean hasHref() {
    return this.href != null;
  }
  
  /**
   * Method is deprecated. use withHref instead.
   */
  @java.lang.Deprecated
  public A withNewHref(java.lang.String arg0) {
    return (A)withHref(new String(arg0));
  }
  public java.lang.String getText() {
    return this.text;
  }
  public A withText(java.lang.String text) {
    this.text=text; return (A) this;
  }
  public java.lang.Boolean hasText() {
    return this.text != null;
  }
  
  /**
   * Method is deprecated. use withText instead.
   */
  @java.lang.Deprecated
  public A withNewText(java.lang.String arg0) {
    return (A)withText(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CLIDownloadLinkFluentImpl that = (CLIDownloadLinkFluentImpl) o;
    if (href != null ? !href.equals(that.href) :that.href != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(href,  text,  additionalProperties,  super.hashCode());
  }
  
}
